<?php

/**
 * Amibios firmware listing controller.
 *
 * @category   apps
 * @package    amibios
 * @subpackage controllers
 * @author     ClearCenter <developer@clearcenter.com>
 * @copyright  2018 ClearCenter
 * @license    http://www.clearcenter.com/app_license ClearCenter license
 * @link       http://www.clearcenter.com/support/documentation/clearos/amibios/
 */


///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

use \clearos\apps\amibios\Amibios_Library as Amibios_Library;

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * Amibios firmware listing controller.
 *
 * @category   apps
 * @package    amibios
 * @subpackage controllers
 * @author     ClearCenter <developer@clearcenter.com>
 * @copyright  2018 ClearCenter
 * @license    http://www.clearcenter.com/app_license ClearCenter license
 * @link       http://www.clearcenter.com/support/documentation/clearos/amibios/
 */

class Firmware extends ClearOS_Controller
{
    /**
     * Returns firmware form.
     *
     * @return view
     */

    function index()
    {
        // Load dependencies
        //------------------

        $this->load->helper('number');
        $this->lang->load('amibios');
        try {
            $this->load->library('amibios/Firmware_Files_Library');

        } catch (Exception $e) {
            $this->page->view_form('amibios/restart_required', NULL, lang('amibios_app_name'));
            //$this->page->view_exception($e);
            return;
        }

        // Load view data
        //---------------

        try {
            $data['listing'] = $this->firmware_files_library->get_list();
        } catch (Engine_Engine_Exception $e) {
            $this->page->view_exception($e);
            return;
        }

        // Load views
        //-----------

        $this->page->view_form('amibios/firmware', $data, lang('amibios_uploaded_firmware'));
    }

    /**
     * Returns add firmware form.
     *
     * @return view
     */

    function add()
    {
        // Load dependencies
        //------------------

        $this->lang->load('base');
        $this->lang->load('amibios');
        $this->load->library('amibios/Firmware_Files_Library');

        // Handle form submit
        //-------------------

        if ($this->input->post('upload')) {
            $config['upload_path'] = CLEAROS_TEMP_DIR;
            $config['allowed_types'] = 'zip';
            $config['overwrite'] = FALSE;

            try {
                $this->load->library('upload', $config);

                $this->upload->do_upload('firmware_file');

                $data['upload_error'] = $this->upload->display_errors();

                if (empty($data['upload_error'])) {
                    $info = $this->upload->data();

                    $this->firmware_files_library->import_zip($info['file_path'] . '/' . $info['file_name']);

                    $this->page->set_status_added();
                    redirect('/amibios');
                }
            } catch (\clearos\apps\base\Validation_Exception $e) {
                // Cheating a bit here.  Normally we would pre-validate a web form
                // or general input data, but in this case where we need to extract
                // and poke around a zip file to validate.
                $data['import_error'] = $e->getMessage();
            } catch (Exception $e) {
                $this->page->view_exception($e);
                return;
            }
        }

        // Load view data
        //---------------

        $this->page->view_form('amibios/add_firmware', $data, lang('base_upload'));
    }

    /**
     * Delete firmware.
     *
     * @param string $firmware firmware basename
     *
     * @return view
     */

    function delete($firmware)
    {
        $confirm_uri = '/app/amibios/firmware/destroy/' . $firmware;
        $cancel_uri = '/app/amibios/firmware';
        $items = array($firmware);

        $this->page->view_confirm_delete($confirm_uri, $cancel_uri, $items);
    }

    /**
     * Destroys firmware.
     *
     * @param string $firmware firmware basename
     *
     * @return view
     */

    function destroy($firmware)
    {
        // Load libraries
        //---------------

        $this->load->library('amibios/Firmware_Files_Library');

        // Handle form submit
        //-------------------

        try {
            $this->firmware_files_library->delete($firmware);
            $this->page->set_status_deleted();
            redirect('/amibios/firmware');
        } catch (Exception $e) {
            $this->page->view_exception($e);
            return;
        }
    }
    /**
     * Install firmware.
     *
     * @param string $firmware firmware basename
     *
     * @return view
     */

    function install($firmware)
    {
        // Load libraries
        //---------------

        $this->load->library('amibios/Firmware_Files_Library');

        // Handle form submit
        //-------------------

        try {
            $this->firmware_files_library->install($firmware);
            $this->page->set_status_updated();
            redirect('/amibios/firmware');
        } catch (Exception $e) {
            $this->page->view_exception($e);
            return;
        }
    }
}
