<?php

/**
 * Amibios javascript helper.
 *
 * @category   apps
 * @package    amibios
 * @subpackage javascript
 * @author     ClearCenter <developer@clearcenter.com>
 * @copyright  2018 ClearCenter
 * @license    http://www.clearcenter.com/app_license ClearCenter license
 * @link       http://www.clearcenter.com/support/documentation/clearos/amibios/
 */

///////////////////////////////////////////////////////////////////////////////
// B O O T S T R A P
///////////////////////////////////////////////////////////////////////////////

$bootstrap = getenv('CLEAROS_BOOTSTRAP') ? getenv('CLEAROS_BOOTSTRAP') : '/usr/clearos/framework/shared';
require_once $bootstrap . '/bootstrap.php';

///////////////////////////////////////////////////////////////////////////////
// T R A N S L A T I O N S
///////////////////////////////////////////////////////////////////////////////

clearos_load_language('amibios');
clearos_load_language('base');

///////////////////////////////////////////////////////////////////////////////
// J A V A S C R I P T
///////////////////////////////////////////////////////////////////////////////

// TODO: move this to framework
$api_info = file_get_contents('/etc/api.conf');
$api_key = trim(preg_replace('/.*=\s*/', '', $api_info));

header('Content-Type:application/x-javascript');
?>

$(document).ready(function() {

    // Translations
    //-------------

    lang_rescan = '<?php echo lang("amibios_rescan"); ?>';
    lang_scanning = '<?php echo lang("amibios_scanning"); ?>';
    lang_backing_up = '<?php echo lang("amibios_backing_up"); ?>';
    lang_backup = '<?php echo lang("amibios_backup"); ?>';
    lang_status = '<?php echo lang("base_status"); ?>';
    api_key = '<?php echo $api_key ?>';

    // Events
    //-------

    $("#firmware_backup").click(function(e){
        e.preventDefault();
        backupFirmware();
    });

    $("#firmware_rescan").click(function(e){
        e.preventDefault();
        getFirmwareInfo(false);
    });

    // Firmware info widget
    //---------------------

    if ($('#firmware_info_wrapper').length != 0)
        getFirmwareInfo(true);

    ///////////////////////////////////////////////////////////////////////////
    // F U N C T I O N S
    ///////////////////////////////////////////////////////////////////////////

    function backupFirmware() {
        var options = new Object();
        options.text = lang_backing_up;

        $('#firmware_rescan').addClass('hide');
        $('#firmware_backup').addClass('disabled');
        $('#firmware_backup').html(clearos_loading(options));

        $.ajax({
            url: '/api/v1/amibios/firmware/backup',
            method: 'POST',
            dataType: 'json',
            headers: {
                'x-api-key': api_key
            },
            success : function(payload) {
                // FIXME: should probably reload
                showFirmwareInfo();
            },
            error: function (XMLHttpRequest, textStatus, errorThrown) {
                showFirmwareInfo();
            }
        });
    }

    function getFirmwareInfo(useCache) {
        var useCacheFlag = (useCache) ? 1 : 0;
        var options = new Object();
        options.text = lang_scanning;

        $('#firmware_backup').addClass('hide');
        $('#firmware_rescan').addClass('disabled');
        $('#firmware_rescan').html(clearos_loading(options));

        $.ajax({
            url: '/api/v1/amibios/firmware?use_cache=' + useCacheFlag,
            method: 'GET',
            dataType: 'json',
            headers: {
                'x-api-key': api_key
            },
            success : function(payload) {
                $("#firmware_id_text").html(payload.data.firmware_id);
                $("#firmware_guid_text").html(payload.data.firmware_guid);

                showFirmwareInfo();
            },
            error: function (XMLHttpRequest, textStatus, errorThrown) {
                window.setTimeout(getFirmwareInfo, 3000);
            }
        });
    }

    function showFirmwareInfo() {
        $('#firmware_backup').html(lang_backup);
        $('#firmware_rescan').html(lang_rescan);
        $('#firmware_backup').removeClass('disabled');
        $('#firmware_rescan').removeClass('disabled');
        $('#firmware_backup').removeClass('hide');
        $('#firmware_rescan').removeClass('hide');
    }
});

// vim: ts=4 syntax=javascript
